import { ref, computed } from 'vue';
import { defineStore } from 'pinia';
import { AxiosWrapper } from '@/util/axios-wrapper';
import _ from 'lodash';

import type { IQueryType, IQueryResult, IQueryParams } from '@/util/types.util';
const axios = new AxiosWrapper();
const projectApi = {
  url: '/api/util/dbInit/project',
};
const tableApi = {
  url: '/api/util/dbInit/table',
};
const dirApi = {
  url: '/api/util/dbInit/dir',
};
export const useCounterStore = defineStore('counter', () => {
  const count = ref(0);
  const doubleCount = computed(() => count.value * 2);
  function increment() {
    count.value++;
  }
  // #region project
  const projectQuery = async ({ skip = 0, limit = undefined, ...info }: IQueryParams = {}): Promise<IQueryResult> => {
    let cond: IQueryType = {};
    if (skip) cond.skip = skip;
    if (limit) cond.limit = limit;
    cond = { ...cond, ...info };
    const res = await axios.$get(`${projectApi.url}`, cond);
    return res;
  };
  const projectFetch = async (payload: any): Promise<IQueryResult> => {
    const res = await axios.$get(`${projectApi.url}/${payload}`);
    return res;
  };
  const projectCreate = async (payload: any): Promise<IQueryResult> => {
    const res = await axios.$post(`${projectApi.url}`, payload);
    return res;
  };
  const projecUpdate = async (payload: any): Promise<IQueryResult> => {
    const id = _.get(payload, 'id', _.get(payload, '_id'));
    const res = await axios.$post(`${projectApi.url}/${id}`, payload);
    return res;
  };
  const projecDelete = async (payload: any): Promise<IQueryResult> => {
    const res = await axios.$delete(`${projectApi.url}/${payload}`);
    return res;
  };
  // #endregion
  // #region dir
  const dirQuery = async ({ skip = 0, limit = undefined, ...info }: IQueryParams = {}): Promise<IQueryResult> => {
    let cond: IQueryType = {};
    if (skip) cond.skip = skip;
    if (limit) cond.limit = limit;
    cond = { ...cond, ...info };
    const res = await axios.$get(`${dirApi.url}`, cond);
    return res;
  };
  const dirFetch = async (payload: any): Promise<IQueryResult> => {
    const res = await axios.$get(`${dirApi.url}/${payload}`);
    return res;
  };
  const dirCreate = async (payload: any): Promise<IQueryResult> => {
    const res = await axios.$post(`${dirApi.url}`, payload);
    return res;
  };
  const dirUpdate = async (payload: any): Promise<IQueryResult> => {
    const id = _.get(payload, 'id', _.get(payload, '_id'));
    const res = await axios.$post(`${dirApi.url}/${id}`, payload);
    return res;
  };
  const dirDelete = async (payload: any): Promise<IQueryResult> => {
    const res = await axios.$delete(`${dirApi.url}/${payload}`);
    return res;
  };
  // #endregion
  // #region table
  const tableQuery = async ({ skip = 0, limit = undefined, ...info }: IQueryParams = {}): Promise<IQueryResult> => {
    let cond: IQueryType = {};
    if (skip) cond.skip = skip;
    if (limit) cond.limit = limit;
    cond = { ...cond, ...info };
    const res = await axios.$get(`${tableApi.url}`, cond);
    return res;
  };
  const tableFetch = async (payload: any): Promise<IQueryResult> => {
    const res = await axios.$get(`${tableApi.url}/${payload}`);
    return res;
  };
  const tableCreate = async (payload: any): Promise<IQueryResult> => {
    const res = await axios.$post(`${tableApi.url}`, payload);
    return res;
  };
  const tableUpdate = async (payload: any): Promise<IQueryResult> => {
    const id = _.get(payload, 'id', _.get(payload, '_id'));
    const res = await axios.$post(`${tableApi.url}/${id}`, payload);
    return res;
  };
  const tableDelete = async (payload: any): Promise<IQueryResult> => {
    const res = await axios.$delete(`${tableApi.url}/${payload}`);
    return res;
  };
  const getSchema = async (payload: any): Promise<IQueryResult> => {
    const id = _.get(payload, 'id', _.get(payload, '_id'));
    const res = await axios.$post(`${tableApi.url}/schema/${id}`);
    return res;
  };
  // 导出
  const exportData = async (data: any): Promise<IQueryResult> => {
    const res = await axios.$post(`${tableApi.url}/export`, data);
    return res.data;
  };
  // 导出ts
  const exportTSData = async (data: any): Promise<IQueryResult> => {
    const res = await axios.$post(`${tableApi.url}/exportTS`, data);
    return res.data;
  };
  const copy = async (data: any): Promise<IQueryResult> => {
    const res = await axios.$post(`${tableApi.url}/copy`, data);
    return res;
  };
  // #endregion

  return {
    count,
    doubleCount,
    increment,
    projectQuery,
    projectFetch,
    projectCreate,
    projecUpdate,
    projecDelete,
    tableQuery,
    tableFetch,
    tableCreate,
    tableUpdate,
    tableDelete,
    exportData,
    exportTSData,
    dirQuery,
    dirFetch,
    dirCreate,
    dirUpdate,
    dirDelete,
    getSchema,
    copy,
  };
});
